"use strict";

var __assign = this && this.__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.applyTo = void 0;

var types_1 = require("../../libs/types");

var ValueSchemaError_1 = require("../../libs/ValueSchemaError");
/**
 * apply schema
 * @param values input/output values
 * @param options options
 * @param keyStack key stack for error handling
 * @returns applied value
 */


function applyTo(values, options, keyStack) {
  var maxLength = normalizeOptions(options.maxLength); // istanbul ignore next

  if (!(0, types_1.isArray)(values.output)) {
    return false;
  }

  if (values.output.length <= maxLength.length) {
    return false;
  }

  if (maxLength.trims) {
    values.output.splice(maxLength.length);
    return false;
  }

  return ValueSchemaError_1.ValueSchemaError.raise(ValueSchemaError_1.CAUSE.MAX_LENGTH, values, keyStack);
}

exports.applyTo = applyTo;
/**
 * normalize options
 * @param maxLength options
 * @returns normalized options
 */

function normalizeOptions(maxLength) {
  var defaultOptions = {
    length: Number.MAX_SAFE_INTEGER,
    trims: false
  };

  if (maxLength === undefined) {
    return defaultOptions;
  }

  if ((0, types_1.isNumber)(maxLength)) {
    return __assign(__assign({}, defaultOptions), {
      length: maxLength
    });
  }

  return __assign(__assign({}, defaultOptions), maxLength);
}