import { isNumber } from "../../libs/types.mjs";
import { CAUSE, ValueSchemaError } from "../../libs/ValueSchemaError.mjs";
/**
 * apply schema
 * @param values input/output values
 * @param options options
 * @param keyStack key stack for error handling
 * @returns applied value
 */

export function applyTo(values, options, keyStack) {
  const maxValue = normalizeOptions(options.maxValue); // istanbul ignore next

  if (!isNumber(values.output)) {
    return false;
  }

  if (values.output <= maxValue.value) {
    return false;
  }

  if (maxValue.adjusts) {
    values.output = maxValue.value;
    return false;
  }

  return ValueSchemaError.raise(CAUSE.MAX_VALUE, values, keyStack);
}
/**
 * normalize options
 * @param maxValue options
 * @returns normalized options
 */

function normalizeOptions(maxValue) {
  const defaultOptions = {
    value: Number.MAX_SAFE_INTEGER,
    adjusts: false
  };

  if (maxValue === undefined) {
    return defaultOptions;
  }

  if (isNumber(maxValue)) {
    return { ...defaultOptions,
      value: maxValue
    };
  }

  return { ...defaultOptions,
    ...maxValue
  };
}