import { isNumber } from "../../libs/types.mjs";
import { CAUSE, ValueSchemaError } from "../../libs/ValueSchemaError.mjs";
/**
 * apply schema
 * @param values input/output values
 * @param options options
 * @param keyStack key stack for error handling
 * @returns applied value
 */

export function applyTo(values, options, keyStack) {
  const minValue = normalizeOptions(options.minValue); // istanbul ignore next

  if (!isNumber(values.output)) {
    return false;
  }

  if (values.output >= minValue.value) {
    return false;
  }

  if (minValue.adjusts) {
    values.output = minValue.value;
    return false;
  }

  return ValueSchemaError.raise(CAUSE.MIN_VALUE, values, keyStack);
}
/**
 * normalize options
 * @param minValue options
 * @returns normalized options
 */

function normalizeOptions(minValue) {
  const defaultOptions = {
    value: Number.MIN_SAFE_INTEGER,
    adjusts: false
  };

  if (minValue === undefined) {
    return defaultOptions;
  }

  if (isNumber(minValue)) {
    return { ...defaultOptions,
      value: minValue
    };
  }

  return { ...defaultOptions,
    ...minValue
  };
}